import React, { useState } from 'react';
import { NsToggleSectionProps, NsAccordionItem } from '../';

/**
 * NsToggleSection takes prop `title` and prop `children` and toggles
 * children with animation when clicked on title
 *
 * it also has a `defaultOpen` prop, which when true, children is visible
 * by default, otherwise children is hidden by default and toggles between visible
 * and hidden on clicking title
 */
const NsToggleSection = ({
    title,
    content,
    additionalProps,
    defaultOpen,
    variant,
    invert,
    isChild,
    type,
}: NsToggleSectionProps) => {
    const [isExpanded, setIsExpanded] = useState(defaultOpen ?? false);

    const toggleAccordion = () => {
        setIsExpanded(!isExpanded);
    };
    return (
        <NsAccordionItem
            type={type}
            level={2}
            variant={variant}
            additionalProps={additionalProps}
            isOpen={isExpanded}
            title={title}
            content={content}
            toggleOpen={toggleAccordion}
            invert={invert}
            isChild={isChild}
        />
    );
};

export default NsToggleSection;
