/* eslint-disable max-len */
import { styled, css, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';

const { color } = ColorUtils;

import type { AlertContainerParams, AlertType, AlertParams, TypeMapCSS } from './types';
const gutterWidth = '10px';
const closeButtonWidth = '12px';
const iconWidth = '24px';

const TypeMap: TypeMapCSS = {
    banner: {
        minHeight: '114px',
        padding: '15px 45px',
        contentColumnStart: 'row-center',
        contentColumnEnd: 'row-center',
        barPosition: 'top',
        footVisibility: 'block',
    },
    card: {
        minHeight: '72px',
        padding: '24px 24px',
        contentColumnStart: 'row-left',
        contentColumnEnd: 'row-right',
        barPosition: 'left',
        footDisplay: 'none',
    },
};

const contextType = {
    error: 'red',
    info: 'info',
    notice: 'info',
    success: 'success',
    warning: 'warning',
};

export const AlertContainer = styled.div<AlertContainerParams>`
    display: ${({ visible }) => (visible ? 'block' : 'none')};
    * {
        box-sizing: border-box;
        webkit-font-smoothing: antialiased;
    }
    text-align: left;
`;
//[Todo-Arun] - Fonts should be driven through @next/font and according to theme
const fontFamilyStyles = css`
    font-family: 'proxima-nova', 'OpenSans', 'Pridi', 'NotoSans', 'NotoSansSC', 'NotoSansHebrew', 'NotoSansJapanese',
        'Hiragino Kaku Gothic Pro', 'Yu Gothic Medium', 'Yu Gothic', Meiryo, 'source-han-sans-japanese',
        'source-han-sans-korean', 'source-han-sans-simplified-c', Helvetica, Arial, sans-serif;
`;

export const Alert = styled.div<AlertParams>`
    position: relative;
    display: grid;
    grid-template-columns: [row-left] ${iconWidth} [space] ${gutterWidth} [row-center] auto [space] ${gutterWidth} [row-right] ${closeButtonWidth};
    grid-template-rows: [row1] auto;
    grid-auto-row: auto;
    grid-auto-flow: row;
    background-color: ${color('primary', 'white')};
    border: 1px solid ${color('primary', 'black')};
    min-height: ${({ type }) => TypeMap?.[type]?.minHeight};
    padding: ${({ type }) => TypeMap?.[type]?.padding};
    color: ${(props) => color(contextType?.[props?.context] as FoundationTheme.AppColors, '40')(props)} };
`;

export const AlertCloseButton = styled.div`
    grid-column-start: row-right;
    grid-column-end: row-right;
    grid-row-start: row1;
    grid-row-end: row1;
    align-self: center;
    cursor: pointer;
`;

export const AlertIcon = styled.div`
    grid-column-start: row-left;
    grid-column-end: row-left;
    grid-row-start: row1;
    grid-row-end: row1;
    width: ${iconWidth};
    height: ${iconWidth};
`;

export const AlertHead = styled.div`
    grid-column-start: row-center;
    grid-column-end: row-center;
    grid-row-start: row1;
    grid-row-end: row1;
    display: flex;
    flex-direction: column;
    justify-content: center;
    span {
        ${fontFamilyStyles}
        color: ${color('primary', 'black')};
        font-weight: 600;
        font-size: 18px;
        line-height: 20px;
    }
`;

export const AlertContent = styled.div<{ type: AlertType }>`
    margin-top: 8px;
    color: ${color('primary', 'black')};
    grid-column-start: ${({ type }) => TypeMap?.[type]?.contentColumnStart};
    grid-column-end: ${({ type }) => TypeMap?.[type]?.contentColumnEnd};
`;

export const AlertFoot = styled.div<{ type: AlertType }>`
    margin-top: 8px;
    color: ${color('primary', 'black')};
    display: ${({ type }) => TypeMap?.[type]?.['footDisplay']};
    ${fontFamilyStyles}
    font-weight: 300;
    font-size: 14px;
    line-height: 18px;
`;

export const AlertBody = styled.div`
    ${fontFamilyStyles}
    font-weight: 300;
    font-size: 16px;
    line-height: 21px;
`;
