import Box from '@mui/material/Box';
import { NsImage } from '../';
import { styled } from '@nuskin/foundation-theme';

type NsPostProps = {
    text: string;
    body: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'column' as 'column',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: '350px',
        width: '210px',
        backgroundColor: '#fff',
        '.content': {
            padding: '10px',
            display: 'flex',
            flexDirection: 'column',
            minHeight: '80px',
            justifyContent: 'space-between',
        },
        '.body-title': {
            fontSize: '18px',
            marginBottom: '5px',
            fontWeight: 600,
            display: '-webkit-box',
            '-webkit-box-orient': 'vertical',
            '-webkit-line-clamp': '3',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
        },
        '.body-text': {
            fontSize: '12px',
            color: '#8C8C8C',
            marginBottom: '5px',
        },
    };
});

const NsPost = ({ text, body, backgroundImageUrl, backgroundImageAlt, className }: NsPostProps) => {
    return (
        <CardContainer className={className} data-testid="post-card">
            <div className="image">
                <NsImage height="auto" width="100%" alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <article className="body-title">{text}</article>
                <article className="body-text">{body}</article>
            </div>
        </CardContainer>
    );
};
export default NsPost;
