import { render, screen } from '@/test-utils/index';
import { fireEvent } from '@storybook/testing-library';
import React from 'react';

import { NsIcon, NsIconNameType, NsIconVariants } from './';

describe('NsIcon Component', () => {
    it('1. renders cartBadge icon with custom size and color', () => {
        const { getByTestId } = render(<NsIcon name="cart" size={'medium'} color="secondary" />);
        const icon = getByTestId('icon');
        const svgIcon = icon.querySelector('svg');
        // expect(svgIcon).toHaveClass('MuiSvgIcon-colorSecondary');
        expect(svgIcon).toHaveClass('MuiSvgIcon-fontSizeMedium');
    });

    it('2. renders with testId', () => {
        Object.keys(NsIconVariants).forEach((iconName) => {
            render(<NsIcon name={iconName as NsIconNameType} />);
            const icon = screen.getByTestId(iconName);
            expect(icon).toBeInTheDocument();
        });
    });
    it('3. renders with custom testId', () => {
        const { getByTestId } = render(<NsIcon name="cart" testId="custom-icon" />);
        const icon = getByTestId('custom-icon');
        expect(icon).toBeInTheDocument();
        expect(icon.innerHTML).toContain('svg');
    });

    it('4. throws an error if invalid icon name is provided', () => {
        const consoleErrorSpy = jest.spyOn(console, 'error').mockImplementation(() => {});
        // @ts-ignore
        const { queryByTestId } = render(<NsIcon name="invalidIcon" />);
        expect(queryByTestId('icon')).not.toBeInTheDocument();
        expect(consoleErrorSpy).not.toHaveBeenCalled();
        consoleErrorSpy.mockRestore();
    });
    it('5. renders default color of alertErrorIcon', () => {
        const { getByTestId } = render(<NsIcon name="alertError" size={'medium'} />);
        const icon = getByTestId('alertError');
        expect(icon).toBeInTheDocument();
    });
    it('6. calls onClick event handler', () => {
        const onClick = jest.fn();
        const { getByTestId } = render(<NsIcon name="alertError" size="medium" onClick={onClick} />);
        const icon = getByTestId('alertError');
        expect(icon).toBeInTheDocument();
        fireEvent.click(icon);
        expect(onClick).toHaveBeenCalled();
    });
});
