import React from 'react';
import Dialog from '@mui/material/Dialog';
import { useMediaQuery } from '@mui/material';
import { useTheme } from '@mui/material/styles';
import { ModalVariantMap } from './model/NsModalVariantMap';
import { NsModalProps } from './types';

const NsModal = (props: NsModalProps) => {
    const { open, handleClose, header, body, additionalProps, footer, statusInfo, variant = 'default' } = props;

    const { className, scrollType = 'paper', ariaLabel } = additionalProps || {};

    const { ariaLabelledby = 'alert-dialog-title', ariaDescribedby = 'alert-dialog-description' } = ariaLabel || {};

    const theme = useTheme();

    const fullScreen: boolean = useMediaQuery(theme.breakpoints.down('md'));

    const Component = ModalVariantMap[variant];

    return (
        <Dialog
            data-testid="nsmodal-dialog"
            fullScreen={fullScreen}
            open={open}
            scroll={scrollType}
            onClose={handleClose}
            aria-labelledby={ariaLabelledby}
            aria-describedby={ariaDescribedby}
            className={className}
        >
            <Component {...{ header, handleClose, body, footer, additionalProps, statusInfo, variant, open }} />
        </Dialog>
    );
};

export default NsModal;
