import { ColorUtils, FoundationTheme, styled } from '@nuskin/foundation-theme';
import { HTMLAttributes } from 'react';

import { getDropdownHeadBorder } from '../dropdown/NsDropdown.styled';

const { paletteColor, themeColor } = ColorUtils;

interface SelectLabelProps extends HTMLAttributes<HTMLLabelElement> {
    errorMessage?: string;
}

export const SelectContainer = styled.div<{ disabled: boolean; errorMessage?: string }>`
    position: relative;
    display: inline-block;
    opacity: ${({ disabled }) => (disabled ? '0.5' : '1')};
    color: ${({ theme, errorMessage }) =>
        errorMessage ? paletteColor('error')({ theme }) : paletteColor('primary')({ theme })};
`;
export const SelectMain = styled.div`
    position: relative;
    display: flex;
`;

export const ErrorContainer = styled.div`
    color: ${paletteColor('error')};
`;

export const SelectHead = styled.div<{ type: string; disabled: boolean }>`
    cursor: ${({ disabled }) => (disabled ? 'inherit' : 'pointer')};
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    border: ${getDropdownHeadBorder};
    background: ${paletteColor('primary', 'contrastText')};
    color: ${paletteColor('primary')};
    width: 207px;
    position: relative;
    z-index: 2;
`;

export const SelectButton = styled.div`
    padding-right: 10px;
`;

export const StyledArrowContainer = styled.div`
    display: flex;
    align-items: center;
    padding-top: 30px;
`;

export const SelectList = styled.div<{ borderColor: FoundationTheme.PaletteColors }>`
    position: absolute;
    z-index: 100;
    border: 1px solid ${({ borderColor, theme }) => paletteColor(borderColor)({ theme })};
    padding: 0;
    margin: 0;
    width: -webkit-fill-available;
    color: ${paletteColor('primary', 'main')};
    background-color: ${paletteColor('primary', 'contrastText')};
    max-height: 200px;
    overflow-y: auto;
`;

export const SelectLabel = styled.label<SelectLabelProps>`
    display: block;
    margin-bottom: 5px;
    color: ${({ theme, errorMessage }) =>
        errorMessage ? paletteColor('error')({ theme }) : paletteColor('primary')({ theme })};
}
`;
type StyledSelectOptionType = { showListDivider: boolean };
export const StyledSelectOption = styled('div')<StyledSelectOptionType>(({ showListDivider, theme }) => {
    const dividerColor = themeColor(
        { colorType: 'neutral', variant: '30' },
        { colorType: 'neutral', variant: '20' }
    )({ theme });
    const borderBottom = showListDivider ? dividerColor : 'none';
    const hoveredBg = themeColor(
        { colorType: 'accentColorB', variant: '20' },
        { colorType: 'accentColorB', variant: '40' }
    )({ theme });

    return {
        cursor: 'pointer',
        borderBottom: `1px solid ${borderBottom}`,
        backgroundColor: 'white',
        color: 'black',
        padding: '5px 10px',
        '&.selected-option': {
            backgroundColor: paletteColor('accentColorA')({ theme }),
            color: 'white',
        },
        '&:hover': {
            color: 'white',
            backgroundColor: hoveredBg,
        },
        '&:last-child': {
            borderBottom: 'none',
        },
    };
});
